package com.xxp.carEnter.Model.Api;


import com.xxp.carEnter.Model.BannerBean;
import com.xxp.carEnter.Model.DictBean;
import com.xxp.carEnter.Model.ImageBean;
import com.xxp.carEnter.Model.LoginBean;
import com.xxp.carEnter.Model.MenuBean;
import com.xxp.carEnter.Model.UpLoadFileBean;
import com.xxp.carEnter.Model.UserAllBean;
import com.xxp.library.httpUtil.BasePageResponselm;
import com.xxp.library.httpUtil.BaseResponse;
import com.xxp.library.httpUtil.BaseResponseIm;

import java.io.File;
import java.util.List;

import okhttp3.MultipartBody;
import okhttp3.RequestBody;
import okhttp3.ResponseBody;
import retrofit2.http.Body;
import retrofit2.http.Field;
import retrofit2.http.FormUrlEncoded;
import retrofit2.http.GET;
import retrofit2.http.Headers;
import retrofit2.http.Multipart;
import retrofit2.http.POST;
import retrofit2.http.PUT;
import retrofit2.http.Part;
import retrofit2.http.Path;
import retrofit2.http.Query;
import retrofit2.http.Streaming;
import retrofit2.http.Url;
import rx.Observable;

public interface ApiProtocal {

    /**
     * 登录
     *
     * @param requestBody
     * @return
     */
    @Headers("Content-type:application/json")
    @POST("authority/forapp/mobileLogin")
    Observable<LoginBean> getLoginInFo(@Body RequestBody requestBody);


    /**
     * 获取用户信息
     *
     * @return
     */
//    @Headers("clientType:fy_authority")
    @GET("internal/forapp/inuser/detailByToken")
    Observable<BaseResponse<UserAllBean>> getUserInfo();



    /**
     * 获取banner列表
     * type: 0banner 1广告
     *
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("authority/forapp/system/banner/selbynameNotQuarePage")
    Observable<BaseResponse<List<BannerBean>>> getBannerList(@Query("type") int type, @Query("flag") String flag);


    /**
     * 修改密码
     *
     * @return
     */
    @Headers("clientType:fy_authority")
    @PUT("authority/forapp/system/user/profile/updatePwd")
    Observable<BaseResponse<String>> setNewPwd(@Body RequestBody requestBody);





    /**
     * 获取图片路径
     *
     * @param ids
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("authority/forapp/upload/showSpeedy/{ids}")
    Observable<BaseResponse<List<ImageBean>>> getImageUrls(@Path("ids") String ids);

    /**
     * 获取数据字典
     *
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("authority/forapp/system/dict/data/type/{type}")
    Observable<BaseResponse<List<DictBean>>> getDictAll(@Path("type") String type);


    /**
     * 获取多个数据字典
     *
     * @param type
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("authority/forapp/system/dict/data/getDictByTypes")
    Observable<BaseResponse<List<DictBean>>> getDictMore(@Query("dictTypes") String type);


    /**
     * 通过token获取code
     *
     * @param token
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("authority/forapp/getCodeByToken")
    Observable<BaseResponseIm> getCodeByToken(@Query("token") String token);


    /**
     * 获取我的常用可全菜单
     *
     * @return
     */
    @FormUrlEncoded
    @Headers("clientType:fy_authority")
    @POST("authority/forapp/system/appmodel/selectService")
    Observable<BaseResponse<List<MenuBean>>> getAllServiceMenu(@Field("modelName") String requestBody);


    /**
     * 修改我的常用
     *
     * @param menuIds
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("authority/forapp/system/appmodel/insertUserApp")
    Observable<BasePageResponselm> changMyUseful(@Query(value = "modelId", encoded = true) String menuIds);

    /**
     * 获取消息未读数量
     *
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("workFlow/forapp/messageinstance/getNoReadNumByUserId")
    Observable<BaseResponse<String>> getMessageNum(@Query("sign") String sign);


    /**
     * 修改消息状态已读
     *
     * @param msgId
     * @return
     */
    @Headers("clientType:fy_authority")
    @PUT("workFlow/forapp/messageinstance/readMessage/{businessId}")
    Observable<BasePageResponselm> changeMsgRead(@Path("businessId") String msgId);


    /**
     * 通知变成已读
     *
     * @param requestBody
     * @return
     */
    @FormUrlEncoded
    @Headers("clientType:fy_authority")
    @PUT("internal/forapp/innoticeperson/updateIsRead")
    Observable<BasePageResponselm> changeNoticeRead(@Field("sign") String requestBody);


    /**
     * 获取未读通知数量
     *
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("internal/forapp/innoticeperson/queryIsReadForPerson")
    Observable<BaseResponse<String>> getNoticeUnReadNum();

    /**
     * 上传头像
     *
     * @return
     */
    @Multipart
    @Headers("clientType:fy_authority")
    @POST("authority/forapp/system/user/updateAvatar")
    Observable<BaseResponseIm> uploadHead(@Part List<MultipartBody.Part> partList);


    /**
     * 上传文件
     *
     * @param file
     * @return
     */
    @Multipart
    @Headers("clientType:fy_authority")
    @POST("authority/forapp/upload/uploadSpeedy")
    Observable<BaseResponse<List<UpLoadFileBean>>> upLoadFile(@Part List<MultipartBody.Part> file);


    /**
     * 下载文件
     *
     * @param url
     * @return
     */
    @Streaming
    @GET
    Observable<ResponseBody> download(@Url String url);


    /**
     * 会议签到
     *
     * @param requestBody
     * @return
     */
    @FormUrlEncoded
    @Headers("clientType:fy_authority")
    @PUT("internal/forapp/inmeetingsign/sign")
    Observable<BaseResponseIm> signMeeting(@Field("sign") String requestBody);


    /**
     * 获取实习生是否已读须知
     *
     * @param userId
     * @return
     */
    @Headers("clientType:fy_authority")
    @GET("internal/forapp/intraineenotice/selectRead")
    Observable<BaseResponse<String>> trainerReadIo(@Query("traineeId") String userId);


    /**
     * 取餐
     *
     * @param mealId
     * @return
     */
    @Headers("clientType:fy_authority")
    @PUT("internal/forapp/inmealorder/updateMakeMeal/{mealId}")
    Observable<BaseResponse<String>> getFood(@Path("mealId") String mealId);



}
