package com.xxp.carEnter.base;

import android.app.Dialog;
import android.content.Context;
import android.util.Log;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.xxp.carEnter.Model.Api.ApiProtocal;
import com.xxp.carEnter.Date.StatesValueMap;
import com.xxp.carEnter.Model.DictBean;
import com.xxp.carEnter.Model.ImageBean;
import com.xxp.carEnter.Model.UpLoadFileBean;
import com.xxp.carEnter.Presenter.view.UpLoadFileView;
import com.xxp.carEnter.Util.CacheUtil;
import com.xxp.library.BuildConfig;
import com.xxp.library.Dialog.StyleProgressDialog;
import com.xxp.library.View.ViewUtils.xxToast;
import com.xxp.library.httpUtil.ApiClient;
import com.xxp.library.httpUtil.BaseResponse;
import com.xxp.library.httpUtil.xxSubscriber;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;

import okhttp3.MultipartBody;
import okhttp3.RequestBody;
import okhttp3.ResponseBody;
import rx.Subscriber;
import rx.android.schedulers.AndroidSchedulers;
import rx.functions.Action1;
import rx.schedulers.Schedulers;


public class BasePresenter<T> {
    public ApiProtocal Ip;
    public Context mContext;
    public T mView;
    public Gson gson = new GsonBuilder().disableHtmlEscaping().create();
    private Dialog wattingDialog;
    xxToast toast;

    public BasePresenter(Context context, T view) {
        mContext = context;
        mView = view;
        toast=new xxToast(context);
        Ip = (ApiProtocal) ApiClient.getInstance(ApiProtocal.class).lp;
        wattingDialog = StyleProgressDialog.showLoadingDialog("请稍后···",
                mContext);
    }

    public void showLToast(String main) {
        toast.setToast(main);
    }

    public void getImageUrls(String imgStrs, int requestCode, getImgUrlCallBack callBack) {
        final boolean[] b = {false};
        final List<ImageBean>[] imageBeans = new List[]{null};

        rx.Observable<BaseResponse<List<ImageBean>>> observable = Ip.getImageUrls(imgStrs);
        observable.subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread()).subscribe(new xxSubscriber<List<ImageBean>>() {

            @Override
            public void onSuccess(List<ImageBean> resultBean) {
                callBack.callBack(resultBean, requestCode);
            }

            @Override
            public void onError(String Error) {

            }
        });

    }

    //上传多个文件
    public void uoLoadFiles(List<File> files, UpLoadFileView view) {
        MultipartBody.Builder builder = new MultipartBody.Builder()
                .setType(MultipartBody.FORM)
                //在这里添加服务器除了文件之外的其他参数
                .addFormDataPart("type", "0").addFormDataPart("dir", "");
        for (File fl : files) {
            RequestBody requestBody = RequestBody.create(okhttp3.MediaType.parse("multipart/form-data"), fl);
            builder.addFormDataPart("files", fl.getName(), requestBody);
        }

        List<MultipartBody.Part> parts = builder.build().parts();
        rx.Observable<BaseResponse<List<UpLoadFileBean>>> observable = Ip.upLoadFile(parts);
        observable.subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread()).subscribe(new xxSubscriber<List<UpLoadFileBean>>() {

            @Override
            public void onSuccess(List<UpLoadFileBean> resultBean) {
                view.reUpLoadResult(resultBean);
            }

            @Override
            public void onError(String Error) {

            }
        });
    }

    public void downFile(String id, String writeUrl, CommView view) {

        rx.Observable<ResponseBody> observable = Ip.download(BuildConfig.URL + "authority/upload/downloadSpeedy/" + id);
        observable.subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread()).doOnNext(new Action1<ResponseBody>() {
            @Override
            public void call(ResponseBody responseBody) {
                saveFile(responseBody, writeUrl);
            }
        }).subscribe(new Subscriber<ResponseBody>() {
            @Override
            public void onCompleted() {
                Log.e("下载", "完成可回調");
                view.finishDown();
            }

            @Override
            public void onError(Throwable e) {
                Log.e("下载", e.toString());
                view.erro();
            }

            @Override
            public void onNext(ResponseBody responseBody) {

            }


        });

    }

    public interface getImgUrlCallBack {
        void callBack(List<ImageBean> urlList, int requestCode);
    }

    /***
     * 显示进度条
     */
    public void showProgressDialog() {
        if (!wattingDialog.isShowing()) {
            wattingDialog.show();
        }
    }

    /***
     * 隐藏进度条
     */
    public void dissmissProgressDialog() {
        if (wattingDialog.isShowing()) {
            wattingDialog.dismiss();
        }
    }


    public void saveFile(ResponseBody body, String writeUrl) {
        Log.e("下载", "下载");
        byte[] buf = new byte[2048];
        int len;
        try {

//            FileUtil.getFileAbsolutePath(FileUtil.AUDIO_MP3_BASENAME, meeting, name)
            File file = new File(writeUrl);
            if (!file.exists()) {
                file.createNewFile();
            }
            FileOutputStream fos = new FileOutputStream(file);
            InputStream secInputstream = body.byteStream();
            while ((len = secInputstream.read(buf)) != -1) {
                fos.write(buf, 0, len);
            }
            Log.e("下载", "完成");
            secInputstream.close();
            fos.close();
        } catch (IOException e) {
            e.printStackTrace();
        }

    }

    public interface CommView {
        void finishDown();

        void erro();
    }


    public void getDict(String type) {

        rx.Observable<BaseResponse<List<DictBean>>> observable = Ip.getDictAll(type);
        observable.subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread()).subscribe(new xxSubscriber<List<DictBean>>() {

            @Override
            public void onSuccess(List<DictBean> resultBean) {
                for (DictBean bean : resultBean) {
                    switch (bean.getDictLabel()) {
                        case "Banner显示数量":
                            StatesValueMap.BANERR_NUMBER = Integer.valueOf(bean.getDictValue());
                            break;
                        case "手机消息前缀":
                            StatesValueMap.NET_URL = bean.getDictValue();
                            break;

                        case "时政热点显示数量":
                            StatesValueMap.AD_NUMBER = Integer.valueOf(bean.getDictValue());
                            break;
                        case "法院加班定位中心点":
                            String[] str = bean.getDictValue().split(",");
                            StatesValueMap.COF_LONGTITUDE = Double.parseDouble(str[0]);
                            StatesValueMap.COF_LATITUDE = Double.parseDouble(str[1]);
                            break;
                        case "法院加班定位半径":
                            StatesValueMap.COF_RADIUS = Float.parseFloat(bean.getDictValue());
                            break;
                        case "审批角色":
                            StatesValueMap.COF_HAS_APPROVE = bean.getDictValue().split(",");
                            break;
                        case "是否清除缓存":
                            if (bean.getDictValue().equals("1"))
                            {
                                CacheUtil.clearAllCache(mContext, new CacheUtil.ClearCallBack() {
                                    @Override
                                    public void onBack(boolean suc) {

                                    }
                                });
                            }
                            break;
                    }
                }
            }

            @Override
            public void onError(String Error) {

            }
        });
    }

    public void getDict(String[] types) {
//        String s = StringUtils.join(types, ",");

        rx.Observable<BaseResponse<List<DictBean>>> observable = Ip.getDictMore("RELATION,COMPANY_TYPE,MARRY_STATUS,MARRY_STATUS_CHANGE,EDU_DEGREE,POLITICAL_STATUS");
        observable.subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread()).subscribe(new xxSubscriber<List<DictBean>>() {

            @Override
            public void onSuccess(List<DictBean> resultBean) {
                for (DictBean bean : resultBean) {
                    StatesValueMap.setDictMap(bean);
                }

            }

            @Override
            public void onError(String Error) {

            }
        });
    }

}
